@@ -42,13 +42,9 @@ from bokeh.models.renderers import GlyphRenderer as backend_plot_t  # noqa
 from bokeh.plotting.figure import Figure as backend_figure_t  # noqa
 from bokeh.resources import INLINE  # noqa
 
-from babelplot.backend.brick.html import Show as BackendShow
+from babelplot.backend.brick.html import Show
 from babelplot.backend.specification.implemented import backend_e
-from babelplot.backend.specification.plot import (
-    UNAVAILABLE_for_this_DIM,
-    plot_e,
-    plot_type_h,
-)
+from babelplot.backend.specification.plot import PlotsFromTemplate, plot_e, plot_type_h
 from babelplot.brick.log import LOGGER
 from babelplot.type.dimension import dim_e
 from babelplot.type.figure import figure_t as base_figure_t
@@ -62,19 +58,6 @@ NAME = backend_e.BOKEH.value
 backend_frame_t = backend_figure_t
 
 
-def _NewFrame(
-    _: backend_figure_t,
-    __: int,
-    ___: int,
-    *args,
-    title: str = None,
-    dim: dim_e = dim_e.XY,  # If _, then it is swallowed by kwargs!
-    **kwargs,
-) -> backend_frame_t:
-    """"""
-    return backend_frame_t(*args, title=title, **kwargs)
-
-
 def _NewPlot(
     frame: backend_frame_t,
     type_: plot_type_h | type(backend_plot_t),
@@ -90,40 +73,49 @@ def _NewPlot(
         else:
             LOGGER.error(f"{type_}: Unknown {NAME} graph object.")
 
-    output = plot_function(frame, *args, **kwargs)
-
-    return output, plot_function
+    return plot_function(frame, *args, **kwargs), plot_function
 
 
-def _ContentFromArrangedFrames(
-    _: backend_figure_t, arranged_frames: list[list[Optional[backend_frame_t]]], /
-) -> backend_content_t:
+def _NewFrame(
+    _: backend_figure_t,
+    __: int,
+    ___: int,
+    *args,
+    title: str = None,
+    dim: dim_e = dim_e.XY,  # If _, then it is swallowed by kwargs!
+    **kwargs,
+) -> backend_frame_t:
     """"""
-    n_rows = arranged_frames.__len__()
-    n_cols = arranged_frames[0].__len__()
+    return backend_frame_t(*args, title=title, **kwargs)
+
+
+def _AsHTML(figure: figure_t, /) -> str:
+    """"""
+    n_rows, n_cols = figure.shape
+    arranged_frames = [n_cols * [None] for _ in range(n_rows)]
+    for frame, (row, col) in zip(figure.frames, figure.locations):
+        arranged_frames[row][col] = frame.backend
+    arranged_frames: list[list[backend_frame_t]]
 
     if n_rows > 1:
         if n_cols > 1:
-            output = NewBackendGridLayout(arranged_frames)
+            contents = NewBackendGridLayout(arranged_frames)
         else:
             column = [_row[0] for _row in arranged_frames]
-            output = NewBackendColLayout(column)
+            contents = NewBackendColLayout(column)
     else:
-        output = NewBackendRowLayout(arranged_frames[0])
+        contents = NewBackendRowLayout(arranged_frames[0])
 
-    return output
-
-
-def _HTMLofContent(_, content: backend_content_t, *__, **___) -> str:
-    """"""
-    return HTMLofBackendContent(content, INLINE)
+    return HTMLofBackendContent(contents, INLINE)
 
 
 # noinspection PyTypeChecker
 plot_t: base_plot_t = type("plot_t", (base_plot_t,), {})
 # noinspection PyTypeChecker
 frame_t: base_frame_t = type(
-    "frame_t", (base_frame_t,), {"plot_class": plot_t, "NewBackendPlot": staticmethod(_NewPlot)}
+    "frame_t",
+    (base_frame_t,),
+    {"plot_class": plot_t, "NewBackendPlot": staticmethod(_NewPlot)},
 )
 # noinspection PyTypeChecker
 figure_t: base_figure_t = type(
@@ -133,20 +125,14 @@ figure_t: base_figure_t = type(
         "frame_class": frame_t,
         "NewBackendFigure": backend_figure_t,
         "NewBackendFrame": staticmethod(_NewFrame),
-        "BackendShow": staticmethod(BackendShow),
-        "HTMLofContent": staticmethod(_HTMLofContent),
-        "ContentFromArrangedFrames": staticmethod(_ContentFromArrangedFrames),
+        "BackendShow": Show,
+        "AsHTML": _AsHTML,
     },
 )
 
 
-PLOTS = {
-    plot_e.SCATTER: (
-        UNAVAILABLE_for_this_DIM,
-        backend_frame_t.scatter,
-        UNAVAILABLE_for_this_DIM,
-    ),
-}
+PLOTS = PlotsFromTemplate()
+PLOTS[plot_e.SCATTER][1] = backend_frame_t.scatter
 
 
 TRANSLATIONS = {
