@@ -39,15 +39,10 @@ from plotly.basedatatypes import BasePlotlyType as backend_plot_t  # noqa
 from plotly.graph_objects import Figure as backend_figure_t  # noqa
 from plotly.subplots import make_subplots as NewMultiAxesFigure  # noqa
 
-from babelplot.backend.brick.html import Show as BackendShow
+from babelplot.backend.brick.html import Show
 from babelplot.backend.specification.implemented import backend_e
-from babelplot.backend.specification.plot import (
-    UNAVAILABLE_for_this_DIM,
-    plot_e,
-    plot_type_h,
-)
+from babelplot.backend.specification.plot import PlotsFromTemplate, plot_e, plot_type_h
 from babelplot.brick.log import LOGGER
-from babelplot.type.dimension import dim_e
 from babelplot.type.figure import figure_t as base_figure_t
 from babelplot.type.frame import frame_t as base_frame_t
 from babelplot.type.plot import plot_t as base_plot_t
@@ -56,21 +51,8 @@ from babelplot.type.plot import plot_t as base_plot_t
 NAME = backend_e.PLOTLY.value
 
 
+array_t = nmpy.ndarray
 backend_frame_h = TypeVar("backend_frame_h")
-backend_content_t = backend_figure_t
-
-
-def _NewFrame(
-    figure: backend_figure_t,
-    __: int,
-    ___: int,
-    *args,
-    title: str = None,
-    dim: dim_e = dim_e.XY,  # If _, then it is swallowed by kwargs!
-    **kwargs,
-) -> backend_frame_h:
-    """"""
-    return None
 
 
 def _NewPlot(
@@ -88,44 +70,42 @@ def _NewPlot(
         else:
             LOGGER.error(f"{type_}: Unknown {NAME} graph object.")
 
-    output = plot_function(*args, **kwargs)
-
-    return output, plot_function
+    return plot_function(*args, **kwargs), plot_function
 
 
-def _ContentFromArrangedFrames(
-    figure: backend_figure_t, arranged_plots: list[list[list[backend_plot_t]]], /
-) -> backend_content_t:
+def _NewFrame(*_, **__) -> backend_frame_h:
     """"""
-    n_rows = arranged_plots.__len__()
-    n_cols = arranged_plots[0].__len__()
+    return None
 
+
+def _AsHTML(figure: figure_t, /) -> str:
+    """"""
+    n_rows, n_cols = figure.shape
     if (n_rows > 1) or (n_cols > 1):
+        arranged_plots = [n_cols * [None] for _ in range(n_rows)]
+        for frame, (row, col) in zip(figure.frames, figure.locations):
+            arranged_plots[row][col] = [_plt.backend for _plt in frame.plots]
+
         frame_types = [n_cols * [{}] for _ in range(n_rows)]
         for row, plot_row in enumerate(arranged_plots):
             for col, plot_cell in enumerate(plot_row):
-                print(dir(plot_cell[0]))
                 frame_types[row][col] = {"type": plot_cell[0].type}
+
         contents = NewMultiAxesFigure(rows=n_rows, cols=n_cols, specs=frame_types)
         for row, plot_row in enumerate(arranged_plots, start=1):
             for col, plot_cell in enumerate(plot_row, start=1):
                 for plot in plot_cell:
                     contents.add_trace(plot, row=row, col=col)
     else:
-        contents = figure
-        for plot in arranged_plots[0][0]:
-            contents.add_trace(plot)
+        contents = figure.backend
+        for plot in figure.frames[0].plots:
+            contents.add_trace(plot.backend)
 
-    return contents
-
-
-def _HTMLofContent(_, content: backend_content_t, *__, **___) -> str:
-    """"""
     # Note on include_plotlyjs:
     #     "cdn": works but must be online
     #     True => blank figure if using PySide6.QtWebEngineWidgets.QWebEngineView.setHtml because of html size limit.
     #         See note in babelplot.backend.brick.html.Show
-    return content.to_html(include_plotlyjs=True)
+    return contents.to_html(include_plotlyjs=True)
 
 
 # noinspection PyTypeChecker
@@ -144,34 +124,40 @@ figure_t: base_figure_t = type(
         "frame_class": frame_t,
         "NewBackendFigure": backend_figure_t,
         "NewBackendFrame": staticmethod(_NewFrame),
-        "BackendShow": staticmethod(BackendShow),
-        "HTMLofContent": staticmethod(_HTMLofContent),
-        "ContentFromArrangedFrames": staticmethod(_ContentFromArrangedFrames),
+        "BackendShow": Show,
+        "AsHTML": _AsHTML,
     },
 )
 
 
-def _Scatter2(*args, **kwargs) -> backend_plot_t:
+def _Scatter2(x, y, **kwargs) -> backend_plot_t:
     """"""
-    x, y = args
-
     return plly.Scatter(x=x, y=y, mode="markers", **kwargs)
 
 
-def _Scatter3(*args, **kwargs) -> backend_plot_t:
+def _Scatter3(x, y, z, **kwargs) -> backend_plot_t:
     """"""
-    x, y, z = args
-
     return plly.Scatter3d(x=x, y=y, z=z, mode="markers", **kwargs)
 
 
-def _Polyline2(*args, **kwargs) -> backend_plot_t:
+def _Polyline2(x, y, **kwargs) -> backend_plot_t:
     """"""
-    x, y = args
-
     return plly.Scatter(x=x, y=y, mode="lines", **kwargs)
 
 
+def _Polyline3(x, y, z, **kwargs) -> backend_plot_t:
+    """"""
+    return plly.Scatter3d(x=x, y=y, z=z, mode="lines", **kwargs)
+
+
+def _Polygon(xs: array_t, ys: array_t, *_, **kwargs) -> backend_plot_t:
+    """"""
+    xs = nmpy.concatenate((xs, [xs[0]]))
+    ys = nmpy.concatenate((ys, [ys[0]]))
+
+    return plly.Scatter(x=xs, y=ys, mode="lines", fill="toself", **kwargs)
+
+
 def _ElevationSurface(*args, **kwargs) -> backend_plot_t:
     """"""
     if args.__len__() == 1:
@@ -185,6 +171,65 @@ def _ElevationSurface(*args, **kwargs) -> backend_plot_t:
     return plly.Surface(contours={}, x=x, y=y, z=elevation, **kwargs)
 
 
+def _Isocontour(*args, **kwargs) -> backend_plot_t:
+    """"""
+    if args.__len__() == 2:
+        x = y = None
+        values, value = args
+    else:
+        x, y, values, value = args
+    parameters = {
+        "z": values,
+        "contours": {"start": value, "end": value, "size": 1, "showlabels": True},
+        "contours_coloring": "lines",
+        "line_width": 2,
+    }
+    if x is not None:
+        parameters["x"] = x
+        parameters["y"] = y
+    parameters.update(kwargs)
+
+    return plly.Contour(**parameters)
+
+
+def _Isosurface(values, value, **kwargs) -> backend_plot_t:
+    """"""
+    if ("X" in kwargs) and ("Y" in kwargs) and ("Z" in kwargs):
+        x = kwargs["x"]
+        y = kwargs["y"]
+        z = kwargs["z"]
+    else:
+        x, y, z = nmpy.meshgrid(
+            range(values.shape[0]),
+            range(values.shape[1]),
+            range(values.shape[2]),
+            indexing="ij",
+        )
+
+    return plly.Isosurface(
+        x=x.flatten(),
+        y=y.flatten(),
+        z=z.flatten(),
+        value=values.flatten(),
+        isomin=value,
+        isomax=value,
+        surface={"count": 1},
+        caps={"x_show": False, "y_show": False, "z_show": False},
+    )
+
+
+def _Mesh(triangles: array_t, vertices: array_t, **kwargs) -> backend_plot_t:
+    """"""
+    return plly.Mesh3d(
+        x=vertices[:, 0],
+        y=vertices[:, 1],
+        z=vertices[:, 2],
+        i=triangles[:, 0],
+        j=triangles[:, 1],
+        k=triangles[:, 2],
+    )
+
+
 def _BarH(*args, **kwargs) -> backend_plot_t:
     """"""
     return _BarV(*args, orientation="h", **kwargs)
@@ -203,68 +248,57 @@ def _BarV(*args, **kwargs) -> backend_plot_t:
     return plly.Bar(x=positions, y=counts, **kwargs)
 
 
-PLOTS = {
-    plot_e.SCATTER: (
-        UNAVAILABLE_for_this_DIM,
-        _Scatter2,
-        _Scatter3,
-    ),
-    plot_e.POLYLINE: (
-        UNAVAILABLE_for_this_DIM,
-        _Polyline2,
-        UNAVAILABLE_for_this_DIM,
-    ),
-    plot_e.POLYGON: (
-        UNAVAILABLE_for_this_DIM,
-        UNAVAILABLE_for_this_DIM,
-        UNAVAILABLE_for_this_DIM,
-    ),
-    plot_e.ARROWS: (
-        UNAVAILABLE_for_this_DIM,
-        UNAVAILABLE_for_this_DIM,
-        UNAVAILABLE_for_this_DIM,
-    ),
-    plot_e.ELEVATION: (
-        UNAVAILABLE_for_this_DIM,
-        UNAVAILABLE_for_this_DIM,
-        _ElevationSurface,
-    ),
-    plot_e.ISOSET: (
-        UNAVAILABLE_for_this_DIM,
-        plly.Contour,
-        plly.Isosurface,
-    ),
-    plot_e.MESH: (
-        UNAVAILABLE_for_this_DIM,
-        UNAVAILABLE_for_this_DIM,
-        plly.Mesh3d,
-    ),
-    plot_e.BARH: (
-        UNAVAILABLE_for_this_DIM,
-        _BarH,
-        UNAVAILABLE_for_this_DIM,
-    ),
-    plot_e.BARV: (
-        UNAVAILABLE_for_this_DIM,
-        _BarV,
-        UNAVAILABLE_for_this_DIM,
-    ),
-    plot_e.BAR3: (
-        UNAVAILABLE_for_this_DIM,
-        UNAVAILABLE_for_this_DIM,
-        UNAVAILABLE_for_this_DIM,
-    ),
-    plot_e.PIE: (
-        UNAVAILABLE_for_this_DIM,
-        UNAVAILABLE_for_this_DIM,
-        UNAVAILABLE_for_this_DIM,
-    ),
-    plot_e.IMAGE: (
-        UNAVAILABLE_for_this_DIM,
-        UNAVAILABLE_for_this_DIM,
-        UNAVAILABLE_for_this_DIM,
-    ),
-}
+def _Pie(values, **kwargs) -> backend_plot_t:
+    """"""
+    return plly.Pie(values=values)
+
+
+def _Image(image: array_t, **kwargs) -> backend_plot_t:
+    """"""
+    if image.ndim == 2:
+        return plly.Heatmap(z=image)
+
+    return plly.Image(z=image)
+
+
+def _Text2(text, x, y, **kwargs) -> backend_plot_t:
+    """"""
+    return plly.Scatter(
+        x=[x], y=[y], text=[text], textposition="top right", mode="text", **kwargs
+    )
+
+
+def _Text3(text, x, y, z, **kwargs) -> backend_plot_t:
+    """"""
+    return plly.Scatter3d(
+        x=[x],
+        y=[y],
+        z=[z],
+        text=[text],
+        textposition="top right",
+        mode="text",
+        **kwargs,
+    )
+
+
+PLOTS = PlotsFromTemplate()
+
+PLOTS[plot_e.SCATTER][1] = _Scatter2
+PLOTS[plot_e.POLYLINE][1] = _Polyline2
+PLOTS[plot_e.POLYGON][1] = _Polygon
+PLOTS[plot_e.ISOSET][1] = _Isocontour
+PLOTS[plot_e.BARH][1] = _BarH
+PLOTS[plot_e.BARV][1] = _BarV
+PLOTS[plot_e.PIE][1] = _Pie
+PLOTS[plot_e.IMAGE][1] = _Image
+PLOTS[plot_e.TEXT][1] = _Text2
+
+PLOTS[plot_e.SCATTER][2] = _Scatter3
+PLOTS[plot_e.POLYLINE][2] = _Polyline3
+PLOTS[plot_e.ELEVATION][2] = _ElevationSurface
+PLOTS[plot_e.ISOSET][2] = _Isosurface
+PLOTS[plot_e.MESH][2] = _Mesh
+PLOTS[plot_e.TEXT][2] = _Text3
 
 
 TRANSLATIONS = {
