@@ -73,6 +73,7 @@ class plot_e(enum_t):
     BAR3 = "bar3"
     PIE = "pie"
     IMAGE = "image"
+    TEXT = "text"
 
     @classmethod
     def PlotsIssues(cls, plots: dict, /) -> Optional[Sequence[str]]:
@@ -299,9 +300,22 @@ PLOT_DESCRIPTION = {
         'Optional argument: An axis-aligned plane position passed as a keyword argument "x", "y", or "z".',
         (2, 3),
     ),
+    plot_e.TEXT: (
+        "Text annotation in two or three dimensions",
+        "Text annotation in two or three dimensions.\n"
+        "Required argument: TEXT, and X, Y, and Z position (depending on the dimension).",
+        (2, 3),
+    ),
 }
 
 
+def PlotsFromTemplate() -> dict[
+    plot_e, list[type(UNAVAILABLE_for_this_DIM) | Callable]
+]:
+    """"""
+    return {_key: 3 * [UNAVAILABLE_for_this_DIM] for _key in PLOT_DESCRIPTION.keys()}
+
+
 def TranslatedArguments(
     who_s_asking: Optional[str | Callable],
     args: Sequence[Any],
