@@ -32,7 +32,7 @@
 import itertools as ittl
 
 import numpy as nmpy
-import scipy as scpy
+from skimage.filters import gaussian as FilteredWithGaussian
 
 from babelplot import NewBabelPlotFigure, ShowAllFigures
 
@@ -51,11 +51,15 @@ figure = NewBabelPlotFigure()
 
 frame = figure.AddFrame(title="SCATTER PLOT 2-D")
 frame.AddPlot("scatter", scatter_x, scatter_y, size=sizes, color=colors, alpha=0.5)
+frame.AddPlot("text", "First sample", scatter_x[0], scatter_y[0], alpha=0.5)
 
 frame = figure.AddFrame(title="SCATTER PLOT 3-D", dim="xyz", col=1)
 frame.AddPlot(
     "scatter", scatter_x, scatter_y, scatter_z, size=sizes, color=colors, alpha=0.5
 )
+frame.AddPlot(
+    "text", "First sample", scatter_x[0], scatter_y[0], scatter_z[0], alpha=0.5
+)
 
 # --- Line plots
 n_vertices = 5
@@ -98,8 +102,8 @@ frame.AddPlot("arrows", 4, 4, 5, arrows_x, arrows_y, arrows_z, color=arrow_color
 # --- Image-based plots
 side = 100
 volume = nmpy.random.random((side + 40, side + 20, side))
+volume = FilteredWithGaussian(volume, 3)
 elevation = volume[:, :, 0]
-elevation = scpy.ndimage.gaussian_filter(elevation, 3)
 
 figure = NewBabelPlotFigure()
 
@@ -119,7 +123,7 @@ frame = figure.AddFrame(title="ISOSURFACE", dim="xyz", col=3)
 frame.AddPlot(
     "isoset",
     volume,
-    0.85 * nmpy.amax(volume),
+    nmpy.median(volume),
     step_size=5,
     width_edge=0.5,
     color_face="r",
@@ -127,7 +131,7 @@ frame.AddPlot(
 )
 
 # --- Mesh plot
-triangles = tuple(ittl.combinations(range(4), 3))
+triangles = nmpy.array(tuple(ittl.combinations(range(4), 3)))
 vertices = []
 for x in (-1.0, 1.0):
     vertices.append([x, 0.0, -1.0 / nmpy.sqrt(2.0)])
@@ -154,7 +158,7 @@ frame.AddPlot("barh", counts, color="r")
 frame.SetProperty("aspect", 0.6)
 
 frame = figure.AddFrame(title="BAR V", col=1)
-frame.AddPlot("barv", range(1, counts.size + 1), counts, color="g")
+frame.AddPlot("barv", tuple(range(1, counts.size + 1)), counts, color="g")
 frame.SetProperty("aspect", "equal")
 
 frame = figure.AddFrame(title="PIE", col=2)
