@@ -172,6 +172,10 @@ class figure_t(base_figure_t):
 
         self.RemoveBackendFrame(frame.backend, self.backend)
 
+    def AsHTML(self) -> str:
+        """"""
+        raise NotImplemented(f"{figure_t.AsHTML.__name__}: Not provided by backend.")
+
     def Clear(self) -> None:
         """"""
         # Do not use a for-loop since self.frames will be modified during looping
@@ -191,19 +195,14 @@ class figure_t(base_figure_t):
         if self.frames.__len__() == 0:
             return
 
-        _unshown_figures.remove(self)
         # /!\ Must be removed when closed
         _shown_figures.append(self)
-
-        if hasattr(self, "BackendPrepareForShow"):
-            self.BackendPrepareForShow(
-                self.backend, self.shape, self.frames, self.locations
-            )
+        _unshown_figures.remove(self)
 
         if modal:
-            self.BackendShow(self)
+            self.BackendShow()
         else:
-            thread = process_t(target=lambda: self.BackendShow(self))
+            thread = process_t(target=lambda: self.BackendShow())
             thread.start()
 
     @staticmethod
@@ -228,9 +227,8 @@ class figure_t(base_figure_t):
             f"{figure_t.RemoveBackendFrame.__name__}: Not provided by backend."
         )
 
-    @staticmethod
     def BackendShow(
-        figure: backend_figure_h,
+        self: figure_t,
         /,
     ) -> None:
         """"""
@@ -246,10 +244,9 @@ def ShowAllFigures(
     """"""
     if all(_fgr.pbe == backend_e.MATPLOTLIB.value for _fgr in _unshown_figures):
         for figure in _unshown_figures:
-            if hasattr(figure, "BackendPrepareForShow"):
-                figure.BackendPrepareForShow(
-                    figure.backend, figure.shape, figure.frames, figure.locations
-                )
+            figure.AdjustFrameGrid(
+                figure.backend, figure.shape, figure.frames, figure.locations
+            )
 
         # /!\ Must be removed when closed
         _shown_figures.extend(_unshown_figures)
