@@ -32,23 +32,29 @@
 from __future__ import annotations
 
 import dataclasses as dtcl
-from typing import Any, Callable, List, Optional, Union
+from typing import Any, Callable, Optional
 
 from babelplot.backend.runtime import BackendPlots, BackendTranslations
-from babelplot.backend.specification.plot import TranslatedArguments, plot_e
+from babelplot.backend.specification.plot import (
+    TranslatedArguments,
+    plot_type_h,
+)
 from babelplot.type.base import babelplot_element_t as base_frame_t
 from babelplot.type.base import backend_frame_h, backend_plot_h
 from babelplot.type.dimension import FRAME_DIM_FOR_DATA_DIM, dim_e
 from babelplot.type.plot import BackendPlotFromAny, plot_t
 
 
+plot_type_w_pbe_h = plot_type_h | type(backend_plot_h)
+
+
 @dtcl.dataclass(repr=False, eq=False)
 class frame_t(base_frame_t):
     title: str = None
     dim: dim_e = None
     frame_dim: int = dtcl.field(init=False, default=None)
     plot_class: type(plot_t) = dtcl.field(init=False, default=None)
-    plots: List[plot_t] = dtcl.field(init=False, default_factory=list)
+    plots: list[plot_t] = dtcl.field(init=False, default_factory=list)
 
     def __post_init__(self) -> None:
         """"""
@@ -56,7 +62,7 @@ class frame_t(base_frame_t):
 
     def AddPlot(
         self,
-        type_: Union[str, plot_e, type(backend_plot_h)],
+        type_: plot_type_w_pbe_h,
         *args,
         title: str = None,
         **kwargs,
@@ -74,7 +80,7 @@ class frame_t(base_frame_t):
             pbe=self.pbe,
         )
         plot.backend, plot.backend_type = self.NewBackendPlot(
-            type_, plot_function, *args, title=title, **kwargs
+            self.backend, type_, plot_function, *args, title=title, **kwargs
         )
         if hasattr(plot, "BackendDefaultProperties"):
             for name, value in plot.BackendDefaultProperties(plot.backend_type).items():
@@ -99,7 +105,7 @@ class frame_t(base_frame_t):
 
     def NewBackendPlot(
         self,
-        type_: Union[str, plot_e, type(backend_plot_h)],
+        type_: plot_type_w_pbe_h,
         plot_function: Optional[Callable],
         *args,
         title: str = None,
